@@ -21,7 +21,7 @@ Homepage: https://psycopg.org/
 # Copyright (C) 2003-2019 Federico Di Gregorio  <fog@debian.org>
 # Copyright (C) 2020-2021 The Psycopg Team
 #
-# psycopg2CrateCrate_crate is free software: you can redistribute it and/or modify it
+# psycopg2Crate_crate is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
 # by the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -34,7 +34,7 @@ Homepage: https://psycopg.org/
 # You must obey the GNU Lesser General Public License in all respects for
 # all of the code used other than OpenSSL.
 #
-# psycopg2CrateCrate_crate is distributed in the hope that it will be useful, but WITHOUT
+# psycopg2Crate_crate is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
@@ -83,11 +83,11 @@ def connect(dsn=None, connection_factory=None, cursor_factory=None, **kwargs):
 
     The connection parameters can be specified as a string:
 
-        conn = psycopg2CrateCrate_crate.connect("dbname=test user=postgres password=secret")
+        conn = psycopg2Crate_crate.connect("dbname=test user=postgres password=secret")
 
     or using a set of keyword arguments:
 
-        conn = psycopg2CrateCrate_crate.connect(database="test", user="postgres", password="secret")
+        conn = psycopg2Crate_crate.connect(database="test", user="postgres", password="secret")
 
     Or as a mix of both. The basic connection parameters are:
 
