@@ -30,8 +30,8 @@ extensions importing register_json from extras.
 
 import json
 
-from psycopg2Crate._psycopg import ISQLQuote, QuotedString
-from psycopg2Crate._psycopg import new_type, new_array_type, register_type
+from psycopg2._psycopg import ISQLQuote, QuotedString
+from psycopg2._psycopg import new_type, new_array_type, register_type
 
 
 # oids from PostgreSQL 9.2
@@ -172,8 +172,8 @@ def _create_json_typecasters(oid, array_oid, loads=None, name='JSON'):
 
 def _get_json_oids(conn_or_curs, name='json'):
     # lazy imports
-    from psycopg2Crate.extensions import STATUS_IN_TRANSACTION
-    from psycopg2Crate.extras import _solve_conn_curs
+    from psycopg2.extensions import STATUS_IN_TRANSACTION
+    from psycopg2.extras import _solve_conn_curs
 
     conn, curs = _solve_conn_curs(conn_or_curs)
 
