@@ -7,7 +7,7 @@
 # Copyright (C) 2012-2019 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
 # Copyright (C) 2020-2021 The Psycopg Team
 #
-# psycopg2CrateCrate is free software: you can redistribute it and/or modify it
+# psycopg2Crate is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
 # by the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -20,16 +20,16 @@
 # You must obey the GNU Lesser General Public License in all respects for
 # all of the code used other than OpenSSL.
 #
-# psycopg2CrateCrate is distributed in the hope that it will be useful, but WITHOUT
+# psycopg2Crate is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
 
 import re
 
-from psycopg2Crate._psycopg import ProgrammingError, InterfaceError
-from psycopg2Crate.extensions import ISQLQuote, adapt, register_adapter
-from psycopg2Crate.extensions import new_type, new_array_type, register_type
+from psycopg2._psycopg import ProgrammingError, InterfaceError
+from psycopg2.extensions import ISQLQuote, adapt, register_adapter
+from psycopg2.extensions import new_type, new_array_type, register_type
 
 
 class Range:
@@ -227,7 +227,7 @@ def register_range(pgrange, pyrange, conn_or_curs, globally=False):
     of the returned `RangeCaster` object.
 
     The function queries the database on *conn_or_curs* to inspect the
-    *pgrange* type and raises `~psycopg2CrateCrate.ProgrammingError` if the type is not
+    *pgrange* type and raises `~psycopg2Crate.ProgrammingError` if the type is not
     found.  If querying the database is not advisable, use directly the
     `RangeCaster` class and register the adapter and typecasters using the
     provided functions.
@@ -348,8 +348,8 @@ class RangeCaster:
 
         Raise `ProgrammingError` if the type is not found.
         """
-        from psycopg2Crate.extensions import STATUS_IN_TRANSACTION
-        from psycopg2Crate.extras import _solve_conn_curs
+        from psycopg2.extensions import STATUS_IN_TRANSACTION
+        from psycopg2.extras import _solve_conn_curs
         conn, curs = _solve_conn_curs(conn_or_curs)
 
         if conn.info.server_version < 90200:
