@@ -6,7 +6,7 @@
 # Copyright (C) 2018-2019 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
 # Copyright (C) 2020-2021 The Psycopg Team
 #
-# psycopg2CrateCrate is free software: you can redistribute it and/or modify it
+# psycopg2Crate is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
 # by the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -19,7 +19,7 @@
 # You must obey the GNU Lesser General Public License in all respects for
 # all of the code used other than OpenSSL.
 #
-# psycopg2CrateCrate is distributed in the hope that it will be useful, but WITHOUT
+# psycopg2Crate is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
@@ -34,5 +34,5 @@ def lookup(code):
 
     Raise `!KeyError` if the code is not found.
     """
-    from psycopg2Crate._psycopg import sqlstate_errors   # avoid circular import
+    from psycopg2._psycopg import sqlstate_errors   # avoid circular import
     return sqlstate_errors[code]
