@@ -35,19 +35,19 @@ This module holds all the extensions to the DBAPI-2.0 provided by psycopg.
 
 import re as _re
 
-from psycopg2Crate._psycopg import (                             # noqa
+from psycopg2._psycopg import (                             # noqa
     BINARYARRAY, BOOLEAN, BOOLEANARRAY, BYTES, BYTESARRAY, DATE, DATEARRAY,
     DATETIMEARRAY, DECIMAL, DECIMALARRAY, FLOAT, FLOATARRAY, INTEGER,
     INTEGERARRAY, INTERVAL, INTERVALARRAY, LONGINTEGER, LONGINTEGERARRAY,
     ROWIDARRAY, STRINGARRAY, TIME, TIMEARRAY, UNICODE, UNICODEARRAY,
     AsIs, Binary, Boolean, Float, Int, QuotedString, )
 
-from psycopg2Crate._psycopg import (                         # noqa
+from psycopg2._psycopg import (                         # noqa
     PYDATE, PYDATETIME, PYDATETIMETZ, PYINTERVAL, PYTIME, PYDATEARRAY,
     PYDATETIMEARRAY, PYDATETIMETZARRAY, PYINTERVALARRAY, PYTIMEARRAY,
     DateFromPy, TimeFromPy, TimestampFromPy, IntervalFromPy, )
 
-from psycopg2Crate._psycopg import (                             # noqa
+from psycopg2._psycopg import (                             # noqa
     adapt, adapters, encodings, connection, cursor,
     lobject, Xid, libpq_version, parse_dsn, quote_ident,
     string_types, binary_types, new_type, new_array_type, register_type,
@@ -186,7 +186,7 @@ def _param_escape(s,
 
 
 # Create default json typecasters for PostgreSQL 9.2 oids
-from psycopg2Crate._json import register_default_json, register_default_jsonb    # noqa
+from psycopg2._json import register_default_json, register_default_jsonb    # noqa
 
 try:
     JSON, JSONARRAY = register_default_json()
@@ -198,7 +198,7 @@ del register_default_json, register_default_jsonb
 
 
 # Create default Range typecasters
-from psycopg2Crate. _range import Range                              # noqa
+from psycopg2. _range import Range                              # noqa
 del Range
 
 
