@@ -1,4 +1,4 @@
-"""Miscellaneous goodies for psycopg2CrateCrate
+"""Miscellaneous goodies for psycopg2Crate
 
 This module is a generic place used to hold little helper functions
 and classes until a better place in the distribution is found.
@@ -8,7 +8,7 @@ and classes until a better place in the distribution is found.
 # Copyright (C) 2003-2019 Federico Di Gregorio  <fog@debian.org>
 # Copyright (C) 2020-2021 The Psycopg Team
 #
-# psycopg2CrateCrate is free software: you can redistribute it and/or modify it
+# psycopg2Crate is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
 # by the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -21,7 +21,7 @@ and classes until a better place in the distribution is found.
 # You must obey the GNU Lesser General Public License in all respects for
 # all of the code used other than OpenSSL.
 #
-# psycopg2CrateCrate is distributed in the hope that it will be useful, but WITHOUT
+# psycopg2Crate is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
@@ -33,14 +33,14 @@ from collections import namedtuple, OrderedDict
 
 import logging as _logging
 
-import psycopg2Crate
-from psycopg2Crate import extensions as _ext
+import psycopg2
+from psycopg2 import extensions as _ext
 from .extensions import cursor as _cursor
 from .extensions import connection as _connection
 from .extensions import adapt as _A, quote_ident
 from functools import lru_cache
 
-from psycopg2Crate._psycopg import (                             # noqa
+from psycopg2._psycopg import (                             # noqa
     REPLICATION_PHYSICAL, REPLICATION_LOGICAL,
     ReplicationConnection as _replicationConnection,
     ReplicationCursor as _replicationCursor,
@@ -48,18 +48,18 @@ from psycopg2Crate._psycopg import (                             # noqa
 
 
 # expose the json adaptation stuff into the module
-from psycopg2Crate._json import (                                # noqa
+from psycopg2._json import (                                # noqa
     json, Json, register_json, register_default_json, register_default_jsonb)
 
 
 # Expose range-related objects
-from psycopg2Crate._range import (                               # noqa
+from psycopg2._range import (                               # noqa
     Range, NumericRange, DateRange, DateTimeRange, DateTimeTZRange,
     register_range, RangeAdapter, RangeCaster)
 
 
 # Expose ipaddress-related objects
-from psycopg2Crate._ipaddress import register_ipaddress          # noqa
+from psycopg2._ipaddress import register_ipaddress          # noqa
 
 
 class DictCursorBase(_cursor):
@@ -295,7 +295,7 @@ class NamedTupleCursor(_cursor):
     their elements can be accessed both as regular numeric items as well as
     attributes.
 
-        >>> nt_cur = conn.cursor(cursor_factory=psycopg2CrateCrate.extras.NamedTupleCursor)
+        >>> nt_cur = conn.cursor(cursor_factory=psycopg2Crate.extras.NamedTupleCursor)
         >>> rec = nt_cur.fetchone()
         >>> rec
         Record(id=1, num=100, data="abc'def")
@@ -517,7 +517,7 @@ class StopReplication(Exception):
     `~ReplicationCursor.consume_stream()`.
 
     Subclass of `~exceptions.Exception`.  Intentionally *not* inherited from
-    `~psycopg2CrateCrate.Error` as occurrence of this exception does not indicate an
+    `~psycopg2Crate.Error` as occurrence of this exception does not indicate an
     error.
     """
     pass
@@ -536,7 +536,7 @@ class ReplicationCursor(_replicationCursor):
 
         if slot_type == REPLICATION_LOGICAL:
             if output_plugin is None:
-                raise psycopg2Crate.ProgrammingError(
+                raise psycopg2.ProgrammingError(
                     "output plugin name is required to create "
                     "logical replication slot")
 
@@ -544,14 +544,14 @@ class ReplicationCursor(_replicationCursor):
 
         elif slot_type == REPLICATION_PHYSICAL:
             if output_plugin is not None:
-                raise psycopg2Crate.ProgrammingError(
+                raise psycopg2.ProgrammingError(
                     "cannot specify output plugin name when creating "
                     "physical replication slot")
 
             command += "PHYSICAL"
 
         else:
-            raise psycopg2Crate.ProgrammingError(
+            raise psycopg2.ProgrammingError(
                 f"unrecognized replication type: {repr(slot_type)}")
 
         self.execute(command)
@@ -576,7 +576,7 @@ class ReplicationCursor(_replicationCursor):
             if slot_name:
                 command += f"SLOT {quote_ident(slot_name, self)} "
             else:
-                raise psycopg2Crate.ProgrammingError(
+                raise psycopg2.ProgrammingError(
                     "slot name is required for logical replication")
 
             command += "LOGICAL "
@@ -587,7 +587,7 @@ class ReplicationCursor(_replicationCursor):
             # don't add "PHYSICAL", before 9.4 it was just START_REPLICATION XXX/XXX
 
         else:
-            raise psycopg2Crate.ProgrammingError(
+            raise psycopg2.ProgrammingError(
                 f"unrecognized replication type: {repr(slot_type)}")
 
         if type(start_lsn) is str:
@@ -600,14 +600,14 @@ class ReplicationCursor(_replicationCursor):
 
         if timeline != 0:
             if slot_type == REPLICATION_LOGICAL:
-                raise psycopg2Crate.ProgrammingError(
+                raise psycopg2.ProgrammingError(
                     "cannot specify timeline for logical replication")
 
             command += f" TIMELINE {timeline}"
 
         if options:
             if slot_type == REPLICATION_PHYSICAL:
-                raise psycopg2Crate.ProgrammingError(
+                raise psycopg2.ProgrammingError(
                     "cannot specify output plugin options for physical replication")
 
             command += " ("
@@ -750,12 +750,12 @@ def wait_select(conn):
     """Wait until a connection or cursor has data available.
 
     The function is an example of a wait callback to be registered with
-    `~psycopg2CrateCrate.extensions.set_wait_callback()`. This function uses
+    `~psycopg2Crate.extensions.set_wait_callback()`. This function uses
     :py:func:`~select.select()` to wait for data to become available, and
     therefore is able to handle/receive SIGINT/KeyboardInterrupt.
     """
     import select
-    from psycopg2Crate.extensions import POLL_OK, POLL_READ, POLL_WRITE
+    from psycopg2.extensions import POLL_OK, POLL_READ, POLL_WRITE
 
     while True:
         try:
@@ -777,7 +777,7 @@ def wait_select(conn):
 def _solve_conn_curs(conn_or_curs):
     """Return the connection and a DBAPI cursor from a connection or cursor."""
     if conn_or_curs is None:
-        raise psycopg2Crate.ProgrammingError("no connection or cursor provided")
+        raise psycopg2.ProgrammingError("no connection or cursor provided")
 
     if hasattr(conn_or_curs, 'execute'):
         conn = conn_or_curs.connection
@@ -868,7 +868,7 @@ class HstoreAdapter:
         start = 0
         for m in self._re_hstore.finditer(s):
             if m is None or m.start() != start:
-                raise psycopg2Crate.InterfaceError(
+                raise psycopg2.InterfaceError(
                     f"error parsing hstore pair at char {start}")
             k = _bsdec.sub(r'\1', m.group(1))
             v = m.group(2)
@@ -879,7 +879,7 @@ class HstoreAdapter:
             start = m.end()
 
         if start < len(s):
-            raise psycopg2Crate.InterfaceError(
+            raise psycopg2.InterfaceError(
                 f"error parsing hstore: unparsed data after char {start}")
 
         return rv
@@ -955,12 +955,12 @@ def register_hstore(conn_or_curs, globally=False, unicode=False,
 
     The |hstore| contrib module must be already installed in the database
     (executing the ``hstore.sql`` script in your ``contrib`` directory).
-    Raise `~psycopg2CrateCrate.ProgrammingError` if the type is not found.
+    Raise `~psycopg2Crate.ProgrammingError` if the type is not found.
     """
     if oid is None:
         oid = HstoreAdapter.get_oids(conn_or_curs)
         if oid is None or not oid[0]:
-            raise psycopg2Crate.ProgrammingError(
+            raise psycopg2.ProgrammingError(
                 "hstore type not found in the database. "
                 "please install it from your 'contrib/hstore.sql' file")
         else:
@@ -1017,7 +1017,7 @@ class CompositeCaster:
 
         tokens = self.tokenize(s)
         if len(tokens) != len(self.atttypes):
-            raise psycopg2Crate.DataError(
+            raise psycopg2.DataError(
                 "expecting %d components for the type %s, %d found instead" %
                 (len(self.atttypes), self.name, len(tokens)))
 
@@ -1051,7 +1051,7 @@ class CompositeCaster:
         rv = []
         for m in self._re_tokenize.finditer(s):
             if m is None:
-                raise psycopg2Crate.InterfaceError(f"can't parse type: {s!r}")
+                raise psycopg2.InterfaceError(f"can't parse type: {s!r}")
             if m.group(1) is not None:
                 rv.append(None)
             elif m.group(2) is not None:
@@ -1106,7 +1106,7 @@ ORDER BY attnum;
             pass
 
         if not recs:
-            raise psycopg2Crate.ProgrammingError(
+            raise psycopg2.ProgrammingError(
                 f"PostgreSQL type '{name}' not found")
 
         type_oid = recs[0][0]
@@ -1249,7 +1249,7 @@ def execute_values(cur, sql, argslist, template=None, page_size=100, fetch=False
         [(1, 20, 3), (4, 50, 6), (7, 8, 9)])
 
     '''
-    from psycopg2Crate.sql import Composable
+    from psycopg2.sql import Composable
     if isinstance(sql, Composable):
         sql = sql.as_string(cur)
 
