@@ -25,11 +25,11 @@ This module implements thread-safe (and not) connection pools.
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
 
-import psycopg2Crate
-from psycopg2Crate import extensions as _ext
+import psycopg2
+from psycopg2 import extensions as _ext
 
 
-class PoolError(psycopg2Crate.Error):
+class PoolError(psycopg2.Error):
     pass
 
 
@@ -60,7 +60,7 @@ class AbstractConnectionPool:
 
     def _connect(self, key=None):
         """Create a new connection and assign it to 'key' if not None."""
-        conn = psycopg2Crate.connect(*self._args, **self._kwargs)
+        conn = psycopg2.connect(*self._args, **self._kwargs)
         if key is not None:
             self._used[key] = conn
             self._rused[id(conn)] = key
