@@ -26,7 +26,7 @@
 
 import string
 
-from psycopg2Crate import extensions as ext
+from psycopg2 import extensions as ext
 
 
 _formatter = string.Formatter()
